Partitionable

Trait Partitionable 

pub trait Partitionable<C, R> {
    type PartitionedState: PartitionedState<C, R>;

    // Required method
    fn new(parts: usize) -> Self::PartitionedState;
}
A trait for command–response pairs that can be partitioned across multiple workers via Partitioned.

Required Associated Types

type PartitionedState: PartitionedState<C, R>

The type which functions as the state machine for the partitioning.

Required Methods

fn new(parts: usize) -> Self::PartitionedState

Construct a PartitionedState for the command–response pair.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors